/*!
* \file controleur.c
* \brief Fichier contenant le code des fonctions du controleur.
*/

#include <stdio.h>
#include <stdlib.h>

#include "partie.h"
#include "joueur.h"
#include "joueurList.h"
#include "case.h"
#include "personnage.h"
#include "classe.h"
#include "gamePackage.h"
#include "roxml.h"

Partie * partieGlobale;
Game_Package packGlobal;

  /*!
 * \fn void initJeu()
 * \brief La fonction initialise les variable globales du package du jeu et de la Partie
 */
void initJeu(){
    partieGlobale = initPartie();
    packGlobal = Construire_Package();
}

/*!
 * \fn void ajouterUnJoueur(char * nomDuJoueur, EtatsJeu * etat)
 * \brief Fonction ajoutant un Joueur  la Partie et faisant passer la partie  l'tat suivant.
 *        Si le joueur n'a pas correctement t ajout, l'tat reste le mme.
 *
 * \param Le nom du joueur  ajouter  la partie
 */
 void ajouterUnJoueur(char * nomDuJoueur, EtatsJeu * etat){
    Joueur * j = nouveauJoueur();
    if(j!=NULL){
        setNomJoueur(j,nomDuJoueur);
        if(addParticipant(partieGlobale,j)==0){
            *etat =LANCEMENT;
        }
        else{
            *etat=SAISIE_JOUEURS;
        }
    }
    else{
        *etat=SAISIE_JOUEURS;
    }
 }

 /*!
 * \fn char ** obtenirNomsClasses()
 * \brief Fonction renvoyant un tableau de chaine de caractres contenant les noms des Classes.
 *        L'ordre et l'index des noms dans le tableau correspond  l'ordre dans lequel ils sont dfinis
 *        dans le fichier XML.
 *
 * \return un tableau de chaine de charactres (char**).
 */
 char ** obtenirNomsClasses(){
    int i;
    //Allocation du tableau contenant les chaines de charactres
    char ** tabNomClasses = malloc((getNbClasses(packGlobal))*sizeof(char *));
    for(i=0;i<getNbClasses(packGlobal);i++){
        tabNomClasses[i]= malloc(TAILLE_NOMS*sizeof(char));
    }

    //Copie des noms de classes dans le tableau
    for(i=0;i<getNbClasses(packGlobal);i++){
        strncpy(tabNomClasses[i],packGlobal.Classes_Package[i].nom, TAILLE_NOMS);
    }
    return tabNomClasses;
 }

  /*!
 * \fn char ** obtenirSkinsClasses()
 * \brief Fonction renvoyant un tableau de chaine de caractres contenant le chemin vers les Skins des Classes.
 *        L'ordre et l'index des noms dans le tableau correspond  l'ordre dans lequel ils sont dfinis
 *        dans le fichier XML.
 *        Ici le chemin du Skin renvoy est celui du "default".
 *
 * \return un tableau de chaine de charactres (char**).
 */
 char ** obtenirSkinsClasses(){
    int i;
    //Allocation du tableau contenant les chaines de charactres
    char ** tabSkinsClasses = malloc((getNbClasses(packGlobal))*sizeof(char *));
    for(i=0;i<getNbClasses(packGlobal);i++){
        tabSkinsClasses[i]= malloc(TAILLE_CHEMIN*sizeof(char));
    }
        //Copie des chemin des skins dans le tableau
    for(i=0;i<getNbClasses(packGlobal);i++){
        strncpy(tabSkinsClasses[i],packGlobal.Classes_Package[i].skins.charac_default, TAILLE_CHEMIN);
    }
    return tabSkinsClasses;
 }









